aboutsummaryrefslogtreecommitdiffstats
path: root/Zotlabs/Web
diff options
context:
space:
mode:
authorredmatrix <git@macgirvin.com>2016-03-31 16:06:03 -0700
committerredmatrix <git@macgirvin.com>2016-03-31 16:06:03 -0700
commit9abd95fad3784a10fc48bc40f9b8a75d7d74edda (patch)
tree3cf2eec6a29f384b80a8c607aa97172b84e37e62 /Zotlabs/Web
parent256c228efd249f2ce93405db8e36f52030aa4876 (diff)
downloadvolse-hubzilla-9abd95fad3784a10fc48bc40f9b8a75d7d74edda.tar.gz
volse-hubzilla-9abd95fad3784a10fc48bc40f9b8a75d7d74edda.tar.bz2
volse-hubzilla-9abd95fad3784a10fc48bc40f9b8a75d7d74edda.zip
static App
Diffstat (limited to 'Zotlabs/Web')
-rw-r--r--Zotlabs/Web/Router.php90
1 files changed, 47 insertions, 43 deletions
diff --git a/Zotlabs/Web/Router.php b/Zotlabs/Web/Router.php
index 900ac1e26..e2e920f39 100644
--- a/Zotlabs/Web/Router.php
+++ b/Zotlabs/Web/Router.php
@@ -9,9 +9,9 @@ class Router {
/**
*
* We have already parsed the server path into $a->argc and $a->argv
*
* $a->argv[0] is our module name. We will load the file mod/{$a->argv[0]}.php
* and use it for handling our URL request.
* The module file contains a few functions that we call in various circumstances
* and in the following order:
@@ -25,7 +25,9 @@ class Router {
* further processing.
*/
- if(strlen($a->module)) {
+ $module = \App::$module;
+
+ if(strlen($module)) {
/**
*
@@ -34,14 +36,14 @@ class Router {
*
*/
- if(is_array($a->plugins) && in_array($a->module,$a->plugins) && file_exists("addon/{$a->module}/{$a->module}.php")) {
- include_once("addon/{$a->module}/{$a->module}.php");
- if(function_exists($a->module . '_module'))
- $a->module_loaded = true;
+ if(is_array(\App::$plugins) && in_array(\App::$module,\App::$plugins) && file_exists("addon/{$module}/{\$module}.php")) {
+ include_once("addon/{$module}/{$module}.php");
+ if(function_exists($module . '_module'))
+ \App::$module_loaded = true;
}
- if((strpos($a->module,'admin') === 0) && (! is_site_admin())) {
- $a->module_loaded = false;
+ if((strpos($module,'admin') === 0) && (! is_site_admin())) {
+ \App::$module_loaded = false;
notice( t('Permission denied.') . EOL);
goaway(z_root());
}
@@ -51,17 +53,19 @@ class Router {
* Otherwise, look for the standard program module in the 'mod' directory
*/
- if(! $a->module_loaded) {
- if(file_exists("mod/site/{$a->module}.php")) {
- include_once("mod/site/{$a->module}.php");
- $a->module_loaded = true;
+ if(! (\App::$module_loaded)) {
+ if(file_exists("mod/site/{$module}.php")) {
+ include_once("mod/site/{$module}.php");
+ \App::$module_loaded = true;
}
- elseif(file_exists("mod/{$a->module}.php")) {
- include_once("mod/{$a->module}.php");
- $a->module_loaded = true;
+ elseif(file_exists("mod/{$module}.php")) {
+ include_once("mod/{$module}.php");
+ \App::$module_loaded = true;
}
+ else logger("mod/{$module}.php not found.");
}
+
/**
* This provides a place for plugins to register module handlers which don't otherwise exist on the system.
* If the plugin sets 'installed' to true we won't throw a 404 error for the specified module even if
@@ -69,10 +73,10 @@ class Router {
* The plugin should catch at least one of the module hooks for this URL.
*/
- $x = array('module' => $a->module, 'installed' => false);
+ $x = array('module' => $module, 'installed' => false);
call_hooks('module_loaded', $x);
if($x['installed'])
- $a->module_loaded = true;
+ \App::$module_loaded = true;
/**
* The URL provided does not resolve to a valid module.
@@ -85,14 +89,14 @@ class Router {
* Otherwise we are going to emit a 404 not found.
*/
- if(! $a->module_loaded) {
+ if(! (\App::$module_loaded)) {
// Stupid browser tried to pre-fetch our Javascript img template. Don't log the event or return anything - just quietly exit.
if((x($_SERVER, 'QUERY_STRING')) && preg_match('/{[0-9]}/', $_SERVER['QUERY_STRING']) !== 0) {
killme();
}
- if((x($_SERVER, 'QUERY_STRING')) && ($_SERVER['QUERY_STRING'] === 'q=internal_error.html') && $a->config['system']['dreamhost_error_hack']) {
+ if((x($_SERVER, 'QUERY_STRING')) && ($_SERVER['QUERY_STRING'] === 'q=internal_error.html') && \App::$config['system']['dreamhost_error_hack']) {
logger('index.php: dreamhost_error_hack invoked. Original URI =' . $_SERVER['REQUEST_URI']);
goaway(z_root() . $_SERVER['REQUEST_URI']);
}
@@ -100,13 +104,13 @@ class Router {
logger('index.php: page not found: ' . $_SERVER['REQUEST_URI'] . ' ADDRESS: ' . $_SERVER['REMOTE_ADDR'] . ' QUERY: ' . $_SERVER['QUERY_STRING'], LOGGER_DEBUG);
header($_SERVER['SERVER_PROTOCOL'] . ' 404 ' . t('Not Found'));
$tpl = get_markup_template('404.tpl');
- $a->page['content'] = replace_macros($tpl, array(
+ \App::$page['content'] = replace_macros($tpl, array(
'$message' => t('Page not found.')
));
// pretend this is a module so it will initialise the theme
- $a->module = '404';
- $a->module_loaded = true;
+ \App::$module = '404';
+ \App::$module_loaded = true;
}
}
}
@@ -118,8 +122,8 @@ class Router {
* Call module functions
*/
- if($a->module_loaded) {
- $a->page['page_title'] = $a->module;
+ if(\App::$module_loaded) {
+ \App::$page['page_title'] = \App::$module;
$placeholder = '';
/**
@@ -129,11 +133,11 @@ class Router {
* to over-ride them.
*/
- if(function_exists($a->module . '_init')) {
+ if(function_exists(\App::$module . '_init')) {
$arr = array('init' => true, 'replace' => false);
- call_hooks($a->module . '_mod_init', $arr);
+ call_hooks(\App::$module . '_mod_init', $arr);
if(! $arr['replace']) {
- $func = $a->module . '_init';
+ $func = \App::$module . '_init';
$func($a);
}
}
@@ -167,32 +171,32 @@ class Router {
$func = str_replace('-', '_', current_theme()) . '_init';
$func($a);
}
- elseif (x($a->theme_info, 'extends') && file_exists('view/theme/' . $a->theme_info['extends'] . '/php/theme.php')) {
- require_once('view/theme/' . $a->theme_info['extends'] . '/php/theme.php');
- if(function_exists(str_replace('-', '_', $a->theme_info['extends']) . '_init')) {
- $func = str_replace('-', '_', $a->theme_info['extends']) . '_init';
+ elseif (x(\App::$theme_info, 'extends') && file_exists('view/theme/' . \App::$theme_info['extends'] . '/php/theme.php')) {
+ require_once('view/theme/' . \App::$theme_info['extends'] . '/php/theme.php');
+ if(function_exists(str_replace('-', '_', \App::$theme_info['extends']) . '_init')) {
+ $func = str_replace('-', '_', \App::$theme_info['extends']) . '_init';
$func($a);
}
}
- if(($_SERVER['REQUEST_METHOD'] === 'POST') && (! $a->error)
- && (function_exists($a->module . '_post'))
+ if(($_SERVER['REQUEST_METHOD'] === 'POST') && (! \App::$error)
+ && (function_exists(\App::$module . '_post'))
&& (! x($_POST, 'auth-params'))) {
- call_hooks($a->module . '_mod_post', $_POST);
- $func = $a->module . '_post';
+ call_hooks(\App::$module . '_mod_post', $_POST);
+ $func = \App::$module . '_post';
$func($a);
}
- if((! $a->error) && (function_exists($a->module . '_content'))) {
- $arr = array('content' => $a->page['content'], 'replace' => false);
- call_hooks($a->module . '_mod_content', $arr);
- $a->page['content'] = $arr['content'];
+ if((! \App::$error) && (function_exists(\App::$module . '_content'))) {
+ $arr = array('content' => \App::$page['content'], 'replace' => false);
+ call_hooks(\App::$module . '_mod_content', $arr);
+ \App::$page['content'] = $arr['content'];
if(! $arr['replace']) {
- $func = $a->module . '_content';
+ $func = \App::$module . '_content';
$arr = array('content' => $func($a));
}
- call_hooks($a->module . '_mod_aftercontent', $arr);
- $a->page['content'] .= $arr['content'];
+ call_hooks(\App::$module . '_mod_aftercontent', $arr);
+ \App::$page['content'] .= $arr['content'];
}
}
}
@@ -9,9 +9,9 @@ class Router {
/**
*
- * We have already parsed the server path into $a->argc and $a->argv
+ * We have already parsed the server path into App::$argc and App::$argv
*
@@ -9,9 +9,9 @@ class Router {
*
- * $a->argv[0] is our module name. We will load the file mod/{$a->argv[0]}.php
+ * App::$argv[0] is our module name. We will load the file mod/{App::$argv[0]}.php
* and use it for handling our URL request.
* The module file contains a few functions that we call in various circumstances